/**
 * PatchInformationPanel
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.pkgview;

import javax.swing.*;
import java.awt.*;
import uk.co.petertribble.jumble.JumbleFile;
import java.io.File;
import uk.co.petertribble.jingle.JingleTextPane;

/**
 * Show information about installed files or packages in a set of
 * tabbed panels.
 */
public class PatchInformationPanel extends JTabbedPane {

    private static final int TAB_INFO = 0;
    private static final int TAB_PKGS = 1;
    private static final int TAB_RDME = 2;

    private JingleTextPane tp_info;
    private JingleTextPane tp_pkgs;
    private JingleTextPane tp_rdme;

    /**
     * Creates a new PatchInformationPanel.
     */
    public PatchInformationPanel() {
	PkgResources pkgres = PkgResources.getInstance();

	tp_info = new JingleTextPane();
	tp_pkgs = new JingleTextPane();
	tp_rdme = new JingleTextPane();

	insertTab(pkgres.getString("PKG.INFO"), (Icon) null,
		new JScrollPane(tp_info), (String) null, TAB_INFO);
	insertTab(pkgres.getString("PKG.PKGS"), (Icon) null,
		new JScrollPane(tp_pkgs), (String) null, TAB_PKGS);
	insertTab(pkgres.getString("PKG.RDME"), (Icon) null,
		new JScrollPane(tp_rdme), (String) null, TAB_RDME);
    }

    public void display(SolarisPatch patch) {
	String sinfo = patch.getInfo();
	if (sinfo == null) {
	    updateText(tp_info, "Not available");
	} else {
	    sinfo = sinfo.replace("Installed:", "<tr><td>Installed:</td><td>");
	    sinfo = sinfo.replace("From:", "</td></tr><td>From:</td><td>");
	    sinfo = sinfo.replace("Obsoletes:",
				  "</td></tr><td>Obsoletes:</td><td>");
	    sinfo = sinfo.replace("Requires:",
				  "</td></tr><td>Requires:</td><td>");
	    sinfo = sinfo.replace("Incompatibles:",
				  "</td></tr><td>Incompatibles:</td><td>");
	    StringBuilder sb = new StringBuilder();
	    sb.append("<table border=\"1\">");
	    sb.append(sinfo);
	    sb.append("</td></tr></table>");
	    updateText(tp_info, sb.toString());
	}

	StringBuilder sb = new StringBuilder();
	sb.append("<table>");
	for (SolarisPackage pkg : patch.getPackages()) {
	    sb.append("<tr><td>");
	    sb.append(pkg.toString());
	    sb.append("</td><td>");
	    sb.append(pkg.getDescription());
	    sb.append("</tr>\n");
	}
	sb.append("</table>");
	updateText(tp_pkgs, sb.toString());

	String rtext = "Not available";
	String spname = patch.toString();
	File f = new File("/var/sadm/patch", spname);
	if (f.exists()) {
	    setEnabledAt(TAB_RDME, true);
	    rtext = JumbleFile.getStringContents(new File(f, "README."+spname));
	} else {
	    setEnabledAt(TAB_RDME, false);
	}
	updateText(tp_rdme, rtext);
    }

    private void updateText(JingleTextPane tp, String s) {
	tp.setText(s);
    }
}
