/**
 * PatchList
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.pkgview;

import java.util.*;

/**
 * Stores a list of patches applied to the system.
 */
public class PatchList {

    private Set <SolarisPatch> patchSet;

    public PatchList() {
	this(new PkgList());
    }

    public PatchList(PkgList pkglist) {
	Map <String, SolarisPatch> patchMap =
				new HashMap <String, SolarisPatch> ();
	for (SolarisPackage pkg : pkglist.getPackages()) {
	    String s = pkg.getInfoItem("PATCHLIST");
	    if (s != null) {
		String ss[] = s.split(" ");
		for (int i = 0; i < ss.length; i++) {
		    if (ss[i].matches("\\d\\d\\d\\d\\d\\d-\\d\\d")) {
			SolarisPatch sp = patchMap.get(ss[i]);
			if (sp == null) {
			    String ds[] = ss[i].split("-");
			    sp = new SolarisPatch(ds[0], ds[1]);
			    patchMap.put(ss[i], sp);
			}
			sp.addPackage(pkg);
			sp.setInfo(pkg.getInfoItem("PATCH_INFO_" + ss[i]));
		    }
		}
	    }
	}

	patchSet = new TreeSet <SolarisPatch> (PatchComparator.getInstance());
	patchSet.addAll(patchMap.values());
    }

    public Set <SolarisPatch> getPatches() {
	return patchSet;
    }

}
