/**
 * SolarisPatch
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.pkgview;

import java.util.*;

/**
 * Stores details of a Solaris patch.
 */
public class SolarisPatch {

    private String sid;
    private String srevision;
    private int id;
    private int revision;
    private String info = null;
    private List <SolarisPackage> packages;

    public SolarisPatch(int id, int revision) {
	this.id = id;
	this.revision = revision;
	sid = Integer.toString(id);
	srevision = Integer.toString(revision);
	packages = new ArrayList <SolarisPackage> ();
    }

    public SolarisPatch(String sid, String srevision) {
	id = Integer.parseInt(sid);
	revision = Integer.parseInt(srevision);
	this.sid = sid;
	this.srevision = srevision;
	packages = new ArrayList <SolarisPackage> ();
    }

    public void addPackage(SolarisPackage pkg) {
	packages.add(pkg);
    }

    public List <SolarisPackage> getPackages() {
	return packages;
    }

    public int getId() {
	return id;
    }

    public int getRevision() {
	return revision;
    }

    public void setInfo(String info) {
	// don't overwrite valid data
	if (info != null) {
	    this.info = info;
	}
    }

    public String getInfo() {
	return info;
    }

    /**
     * Returns a String representation of this patch, in the form
     * ######-##
     */
    @Override
    public String toString() {
	return sid + "-" + srevision;
    }

    /**
     * Returns whether the requested Object is equal to this SolarisPatch.
     * Equality implies that the Object is of class SolarisPatch and has
     * the same id and revision.
     *
     * @param o The object to be tested for equality.
     *
     * @return true if the object is a {@code SolarisPatch} with the same
     * id and revision as this {@code SolarisPatch}.
     */
    @Override
    public boolean equals(Object o) {
        if (o instanceof SolarisPatch) {
	    SolarisPatch sp = (SolarisPatch) o;
	    return (id == sp.getId()) && (revision == sp.getRevision());
	}
	return false;
    }
}
