/**
 * FsInfoPanel - shows Filesystem status
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.solview.explorer;

import javax.swing.*;
import uk.co.petertribble.jkstat.api.*;
import uk.co.petertribble.solview.InfoCommand;
import uk.co.petertribble.jingle.JingleTextPane;

public class FsInfoPanel extends InfoPanel {

    private JingleTextPane tp;
    private JKstat jkstat;
    private JFSstatPanel fsPanel;

    /**
     * Display a Memory information panel.
     */
    public FsInfoPanel(SysItem hi, JKstat jkstat) {
	super(hi);
	this.jkstat = jkstat;

	tp = new JingleTextPane("text/plain");

	display();
	validate();
    }

    public void stopLoop() {
	if (fsPanel != null) {
	    fsPanel.stopLoop();
	}
    }

    /*
     * Display an information panel appropriate to the Cpu item that is
     * selected.
     */
    private void display() {
	switch (hi.getType()) {
	    case SysItem.FS_FSSTAT:
		displayFS();
		break;
	    case SysItem.ZFS_FS:
		displayZFS();
		break;
	    case SysItem.FS_CONTAINER:
		displaySummary();
		break;
	    case SysItem.ZFS_CONTAINER:
		displayZSummary();
		break;
	}
    }

    /*
     * Top level summary. just df
     * FIXME output should be lined up in a grid
     */
    private void displaySummary() {
	jvp.add(new JLabel("Filesystem Summary"));
	InfoCommand ic = new InfoCommand("df", "/usr/sbin/df", "-h");
	tp.setText(ic.getOutput());
	jvp.add(new JScrollPane(tp));
    }

    /*
     * Top level summary. just zpool status
     * FIXME output should be lined up in a grid
     */
    private void displayZSummary() {
	jvp.add(new JLabel("ZFS Pool Summary"));
	InfoCommand ic = new InfoCommand("zp", "/usr/sbin/zpool", "status");
	tp.setText(ic.getOutput());
	jvp.add(new JScrollPane(tp));
    }

    /*
     * fsstat
     */
    private void displayFS() {
	jvp.add(new JLabel("Filesystem statistics"));
	fsPanel = new JFSstatPanel(jkstat, 5);
	jvp.add(new JScrollPane(fsPanel));
    }

    /*
     * ZFS filesystem
     *
     * FIXME: use the properties from the object
     */
    private void displayZFS() {
	jvp.add(new JLabel("ZFS Filesystem"));
	Zfilesys zfs = (Zfilesys) hi.getAttribute("zfs");
	InfoCommand ic = new InfoCommand("zf", "/usr/sbin/zfs",
					"get all " + zfs.getName());
	tp.setText(ic.getOutput());
	jvp.add(new JScrollPane(tp));
    }
}
