/*
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License, Version 1.0 only
 * (the "License").  You may not use this file except in compliance
 * with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 */

package uk.co.petertribble.solview.explorer;

import javax.swing.*;
import java.awt.event.*;
import java.awt.*;
import uk.co.petertribble.jingle.JingleVPanel;

public class InfoPanel extends JPanel implements ActionListener {

    protected SysItem hi;
    protected Timer timer;
    protected int delay = 1000;
    protected JingleVPanel jvp;

    /**
     * Create an information panel. Subclasses should call super()
     * with the same arguments as the first part of their constructor,
     * and then have code to actually create the panel contents, and
     * then must call startLoop().
     */
    public InfoPanel(SysItem hi) {
	this.hi = hi;
	setLayout(new BorderLayout());
	jvp = new JingleVPanel();
	jvp.setLayout(new BoxLayout(jvp, BoxLayout.PAGE_AXIS));
	add(jvp);
    }

    /**
     * Subclasses must override this method to update the display
     */
    public void updateAccessory() {
    }

    /**
     * Start the timer loop, so that the accessory updates itself.
     */
    public void startLoop() {
	if (timer == null) {
	    timer = new Timer(delay, this);
	}
	timer.start();
    }

    /**
     * Stop the timer loop, so that the accessory will no longer be updated.
     */
    public void stopLoop() {
	if (timer != null) {
	    timer.stop();
	}
    }

    /**
     * Set the accessory update delay, which should be specified in seconds.
     */
    public void setDelay(int interval) {
	delay = interval*1000;
	if (timer != null) {
	    timer.setDelay(delay);
	}
    }

    public void actionPerformed(ActionEvent e) {
	updateAccessory();
    }
}
