/*
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License, Version 1.0 only
 * (the "License").  You may not use this file except in compliance
 * with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 */

package uk.co.petertribble.solview.explorer;

import javax.swing.*;
import uk.co.petertribble.jkstat.api.*;
import uk.co.petertribble.jkstat.util.NumericStringComparator;
import uk.co.petertribble.jingle.JingleVPanel;
import java.util.*;

public class JKmemPanel extends JingleVPanel {

    private List <AccessoryKmemAlloc> vkstat;

    // all kmem kstats have names starting kmem_alloc_
    private static final String alloc_prefix = "kmem_alloc_";

    public JKmemPanel(JKstat jkstat, int interval) {

	vkstat = new ArrayList <AccessoryKmemAlloc> ();

	// we lay it out with all the individual accessories atop each other
	setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));

	/*
	 * Filter on all kmem cache kstats
	 */
	KstatFilter ksf = new KstatFilter(jkstat);
	ksf.setFilterClass("kmem_cache");
	ksf.addFilter("unix:0::");

	SortedMap <String, Kstat> kmap = new TreeMap <String, Kstat> (
		NumericStringComparator.getInstance());

	for (Kstat ks : ksf.getKstats()) {
	    if (ks.getName().startsWith(alloc_prefix)) {
		kmap.put(ks.getName(), ks);
	    }
	}
	for (String s : kmap.keySet()) {
	    Kstat ks = kmap.get(s);
	    AccessoryKmemAlloc aka = new AccessoryKmemAlloc(ks.getModule(),
		ks.getInst(), ks.getName(), interval, jkstat);
	    vkstat.add(aka);
	    add(aka);
	}
    }

    /*
     * Propagate delay down to children
     */
    public void setDelay(int i) {
	for (AccessoryKmemAlloc aka : vkstat) {
	    aka.setDelay(i);
	}
    }

    /*
     * stop children
     */
    public void stopLoop() {
	for (AccessoryKmemAlloc aka : vkstat) {
	    aka.stopLoop();
	}
    }
}
