/**
 * MetaDevice - represent an SVM metadevice
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.solview.explorer;

import java.util.Set;
import java.util.HashSet;

public class MetaDevice {

    // possible metadevice types
    public static final int STRIPE = 1;
    public static final int CONCAT = 2;
    public static final int MIRROR = 3;
    public static final int RAID5 = 4;
    public static final int SOFTPART = 5;
    // for historical completeness
    public static final int TRANS = 99;

    private String name;
    private int metatype;
    private int interlace;
    private MetaDevice parent;
    private Set <MetaDevice> children;
    private Set <String> components;

    public MetaDevice(String name, int metatype) {
	this.name = name;
	this.metatype = metatype;
	children = new HashSet <MetaDevice> ();
	components = new HashSet <String> ();
    }

    public String getName() {
	return name;
    }

    public int getType() {
	return metatype;
    }

    public String getTypeAsString() {
	String t;
	switch (metatype) {
	    case STRIPE:
		t = "Stripe";
		break;
	    case CONCAT:
		t = "Concatenation";
		break;
	    case MIRROR:
		t = "Mirror";
		break;
	    case RAID5:
		t = "Raid-5";
		break;
	    case SOFTPART:
		t = "Soft Partition";
		break;
	    default:
		t = "Unknown";
	}
	return t;
    }

    // FIXME parents and children don't have to be metadevices
    public void setParent(MetaDevice parent) {
	this.parent = parent;
    }

    public MetaDevice getParent() {
	return parent;
    }

    public void addChild(MetaDevice child) {
	children.add(child);
    }

    public void addComponent(String component) {
	components.add(component);
    }

}
