/**
 * SysPanel - shows hardware in the system
 * @author Peter Tribble
 * @version 1.0
 *
 */

package uk.co.petertribble.solview.explorer;

import javax.swing.*;
import javax.swing.tree.*;
import javax.swing.event.*;
import java.awt.*;
import uk.co.petertribble.jkstat.api.JKstat;
import uk.co.petertribble.solview.SolViewResources;

public class SysPanel extends JPanel {

    private SysTree ptree;
    private SysInfoPanel hip;

    /**
     * Display a Sys information panel.
     */
    public SysPanel() {
	this(new JKstat());
    }

    /**
     * Display a Sys information panel.
     *
     * @param jkstat A JKstat object
     */
    public SysPanel(JKstat jkstat) {
	/*
	 * I'm not sure what this will eventually look like. I'm planning
	 * on something that just has big buttons "cpu" "memory" "storage"
	 * "network", but as the underlying data model is a hierarchical
	 * view the initial display is as a tree.
	 */
	setLayout(new BorderLayout());

	SolViewResources svr = SolViewResources.getInstance();

	// FIXEM should hard.title be the name of the system?
	ptree = new SysTree(svr.getString("HARD.TITLE"));
	ptree.addTreeSelectionListener(new TreeSelectionListener() {
	    public void valueChanged(TreeSelectionEvent e) {
		DefaultMutableTreeNode node = (DefaultMutableTreeNode)
		    ptree.getLastSelectedPathComponent();

		if (node != null) {
		    setInfo(node.getUserObject());
		}
	    }
	});
	// end of tree listener


	JTabbedPane jtp = new JTabbedPane();

	jtp.add(svr.getString("HARD.TREE"), new JScrollPane(ptree));

	hip = new SysInfoPanel(jkstat);

	JSplitPane psplit = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT,
		jtp, hip);
	psplit.setOneTouchExpandable(true);
	psplit.setDividerLocation(160);
	add(psplit);
    }

    private void setInfo(Object o) {
	if (o instanceof SysItem) {
	    hip.display((SysItem) o);
	}
    }

}
